@@ -14,7 +14,7 @@ import logging
 
 import numpy as np
 
-from tespy.components.turbomachinery.turbomachine import Turbomachine
+from tespy.components.turbomachinery.base import Turbomachine
 from tespy.tools.data_containers import ComponentCharacteristics as dc_cc
 from tespy.tools.data_containers import ComponentProperties as dc_cp
 from tespy.tools.document_models import generate_latex_eq
@@ -34,7 +34,7 @@ class Pump(Turbomachine):
     **Optional Equations**
 
     - :py:meth:`tespy.components.component.Component.pr_func`
-    - :py:meth:`tespy.components.turbomachinery.turbomachine.Turbomachine.energy_balance_func`
+    - :py:meth:`tespy.components.turbomachinery.base.Turbomachine.energy_balance_func`
     - :py:meth:`tespy.components.turbomachinery.pump.Pump.eta_s_func`
     - :py:meth:`tespy.components.turbomachinery.pump.Pump.eta_s_char_func`
     - :py:meth:`tespy.components.turbomachinery.pump.Pump.flow_char_func`
