@@ -10,8 +10,6 @@ SPDX-License-Identifier: MIT
 """
 import os
 import sys
-from collections.abc import Mapping
-from copy import deepcopy
 from datetime import date
 
 import CoolProp as CP
@@ -62,7 +60,7 @@ def document_model(nw, path='report', filename='report.tex', fmt={}):
         os.makedirs(fig_path)
 
     rpt = set_defaults(nw)
-    rpt = merge_dicts(rpt, fmt)
+    rpt = hlp.merge_dicts(rpt, fmt)
 
     rpt['path'] = path
 
@@ -79,20 +77,6 @@ def document_model(nw, path='report', filename='report.tex', fmt={}):
         f.close()
 
 
-def merge_dicts(dict1, dict2):
-    """Return a new dictionary by merging two dictionaries recursively."""
-
-    result = deepcopy(dict1)
-
-    for key, value in dict2.items():
-        if isinstance(value, Mapping):
-            result[key] = merge_dicts(result.get(key, {}), value)
-        else:
-            result[key] = deepcopy(dict2[key])
-
-    return result
-
-
 def set_defaults(nw):
     """
     Set up defaults for report formatting.
